@@ -149,9 +149,7 @@ void BlockAlarmsAttribute::deserialize(const QByteArray &data)
     }
 }
 
-namespace
-{
-
+namespace {
 // Anonymous namespace; function is invisible outside this file.
 bool dummy()
 {
@@ -162,6 +160,4 @@ bool dummy()
 
 // Called when this library is loaded.
 const bool registered = dummy();
-
 } // namespace
-
